package net.xdclass.shopmanager.tool.service;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;
import org.springframework.stereotype.Component;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.support.DefaultTransactionDefinition;

/**
 * @author holly
 * @date 2023/4/13
 * @description 事务控制
 */
@Component
public class TransactionService {
    @Autowired
    private DataSourceTransactionManager transactionManager;

    /**
     * 开启新事务
     */
    public TransactionStatus begin() {
        DefaultTransactionDefinition def = new DefaultTransactionDefinition();
        //事物隔离级别(读已提交)
        def.setIsolationLevel(TransactionDefinition.ISOLATION_READ_COMMITTED);
        //默认事务
        return transactionManager.getTransaction(def);
    }

    /**
     * 开启事务
     */
    public TransactionStatus begin(int isolationLevel, int propagationBehavior) {
        DefaultTransactionDefinition def = new DefaultTransactionDefinition();
        //事物隔离级别
        def.setIsolationLevel(isolationLevel);
        //事务传播行为
        def.setPropagationBehavior(propagationBehavior);
        //默认事务
        return transactionManager.getTransaction(def);
    }

    /**
     * 提交事务
     */
    public void commit(TransactionStatus transactionStatus) {
        //提交事务
        transactionManager.commit(transactionStatus);
    }

    /**
     * 回滚事务
     */
    public void rollback(TransactionStatus transactionStatus) {
        transactionManager.rollback(transactionStatus);
    }
}